==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm5/lib/igc-tile-series-component.js <==
import { __extends } from "tslib";
import { IgcShapeSeriesBaseComponent } from "igniteui-webcomponents-charts";
import { TileSeries } from "./TileSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Represents a tile series class that can render imagery tiles
*/
var IgcTileSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcTileSeriesComponent, _super);
    function IgcTileSeriesComponent() {
        return _super.call(this) || this;
    }
    IgcTileSeriesComponent.prototype.createImplementation = function () {
        return new TileSeries();
    };
    Object.defineProperty(IgcTileSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcTileSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcTileSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcTileSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent == null) {
                var names = getAllPropertyNames(IgcTileSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent = names;
            }
            return IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcTileSeriesComponent.register = function () {
        if (!IgcTileSeriesComponent._isElementRegistered) {
            IgcTileSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcTileSeriesComponent.htmlTagName, IgcTileSeriesComponent);
        }
    };
    Object.defineProperty(IgcTileSeriesComponent.prototype, "isTile", {
        /**
         * Gets whether the current series shows a tile imagery.
        */
        get: function () {
            return this.i.fh;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcTileSeriesComponent.prototype, "tileImagery", {
        /**
         * The MapImagery which is used to provide the tiles for display.
        */
        get: function () {
            var r = this.i.wy;
            if (r == null) {
                return null;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.wy = null : this.i.wy = v.i;
        },
        enumerable: false,
        configurable: true
    });
    IgcTileSeriesComponent.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.tileImagery && this.tileImagery.name && this.tileImagery.name == name) {
            return this.tileImagery;
        }
        return null;
    };
    /**
     * Defers rendering of the series
    
    */
    IgcTileSeriesComponent.prototype.deferredRefresh = function () {
        this.i.deferredRefresh();
    };
    IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent = null;
    IgcTileSeriesComponent.htmlTagName = "igc-tile-series";
    IgcTileSeriesComponent._isElementRegistered = false;
    return IgcTileSeriesComponent;
}(IgcShapeSeriesBaseComponent));
export { IgcTileSeriesComponent };

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm5/lib/igc-tile-series-component.js <==
import { __extends } from "tslib";
import { IgcShapeSeriesBaseComponent } from "igniteui-webcomponents-charts";
import { TileSeries } from "./TileSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Represents a tile series class that can render imagery tiles
*/
var IgcTileSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcTileSeriesComponent, _super);
    function IgcTileSeriesComponent() {
        return _super.call(this) || this;
    }
    IgcTileSeriesComponent.prototype.createImplementation = function () {
        return new TileSeries();
    };
    Object.defineProperty(IgcTileSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcTileSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcTileSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcTileSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent == null) {
                var names = getAllPropertyNames(IgcTileSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent = names;
            }
            return IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcTileSeriesComponent.register = function () {
        if (!IgcTileSeriesComponent._isElementRegistered) {
            IgcTileSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcTileSeriesComponent.htmlTagName, IgcTileSeriesComponent);
        }
    };
    Object.defineProperty(IgcTileSeriesComponent.prototype, "isTile", {
        /**
         * Gets whether the current series shows a tile imagery.
        */
        get: function () {
            return this.i.f3;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcTileSeriesComponent.prototype, "tileImagery", {
        /**
         * The MapImagery which is used to provide the tiles for display.
        */
        get: function () {
            var r = this.i.aad;
            if (r == null) {
                return null;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.aad = null : this.i.aad = v.i;
        },
        enumerable: false,
        configurable: true
    });
    IgcTileSeriesComponent.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.tileImagery && this.tileImagery.name && this.tileImagery.name == name) {
            return this.tileImagery;
        }
        return null;
    };
    /**
     * Defers rendering of the series
    
    */
    IgcTileSeriesComponent.prototype.deferredRefresh = function () {
        this.i.deferredRefresh();
    };
    IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent = null;
    IgcTileSeriesComponent.htmlTagName = "igc-tile-series";
    IgcTileSeriesComponent._isElementRegistered = false;
    return IgcTileSeriesComponent;
}(IgcShapeSeriesBaseComponent));
export { IgcTileSeriesComponent };
